@@ -1,4 +1,6 @@
 from .qingpi import Button, Y, B, A, X, L, R, SELECT, START, POWER, WIRELESS, HOME
 from .qingpi import Hat, UP, UPRIGHT, RIGHT, DOWNRIGHT, DOWN, DOWNLEFT, LEFT, UPLEFT
 from .qingpi import SlidePad
-from .qingpi import TouchScreen
\ No newline at end of file
+from .qingpi import TouchScreen
+from .qingpi import init
+from .qingpi import HoldOp, HoldFunction, ReleaseOp, ReleaseFunction
